@@ -4,4 +4,4 @@ TIME = 0
 INDEX = 1
 POINT = 2
 
-by_mthods = [0, 1, 2]
\ No newline at end of file
+by_methods = [0, 1, 2]
\ No newline at end of file
