@@ -1,3 +1,4 @@
+import warnings
 from . import by as _by
 from .parameters import parameters
 import os
@@ -20,7 +21,7 @@ class Tier(object):
         self.tier_type = None
 
     def add_point(self, point):
-        """Add point (Point object) to the Tier.\nUsage:\n\t(1) You can either (a) create a Point object with \'Point()\', or (b) get a specific Point object from already existing Tiers with \'get_point()\'.\n\t(2) Pass it as the argument."""
+        """Add point (Point object) to the Tier.\nUsage:\n\t(1) You can either (a) create a Point object with `Point()`, or (b) get a specific Point object from already existing Tiers with `get_point()`.\n\t(2) Pass it as the argument."""
         point = Point(point.time, point.value, superior_Tier=self)
 
         if point.time < self.start_time or point.time > self.end_time:
@@ -45,7 +46,7 @@ class Tier(object):
         self._indexed = True
 
     def add_points(self, points):
-        """Add a list (array-like) of points (Point object) to the Tier.\nUsage:\n\t(1) You can either (a) create the Point objects with \'Point()\', or (b) get specific Point objects from already existing Tiers with \'get_points()\'.\n\t(2) Pass it as the argument."""
+        """Add a list (array-like) of points (Point object) to the Tier.\nUsage:\n\t(1) You can either (a) create the Point objects with `Point()`, or (b) get specific Point objects from already existing Tiers with `get_points()`.\n\t(2) Pass it as the argument."""
 
         for point in points:
             point = Point(point.time, point.value, superior_Tier=self)
@@ -73,7 +74,7 @@ class Tier(object):
         self._indexed = True
 
     def to_plot(self, start_time=None, end_time=None):
-        """Plot the points of the Tier between two time points. If the time points are not specified, \'start time\' and\\or \'end time\' are used. To change related parameters, use \'parameters\'."""
+        """Plot the points of the Tier between two time points. If the time points are not specified, `start time` and\\or `end time` are used. To change related parameters, use `parameters`."""
 
         if start_time == None:
             start_time = self.start_time
@@ -105,19 +106,43 @@ class Tier(object):
 
         return plot
 
-    def get_point(self, by_target, by):
-        """Get Point of the Tier with chosen method. See \'help(by)\' for more information on the available methods. To change related parameters, use \'parameters\'."""
+    def get_point(self, by_target, by, strict=True, point_type=None):
+        """Get Point of the Tier with chosen method. \n If `strict` set to False, get the closest Point object to the target. If `point_type` set to `larger`, find the closest larger Point; If `point_type` set to `smaller`, find the closest smaller Point.\nSee `help(by)` for more information on the available methods. To change related parameters, use `parameters`."""
 
         if by not in _by.by_methods:
             raise Exception(
                 f'Invalid by_method. Use help() to see valid methods.')
 
         if by == _by.TIME:
-            for point in self.__points:
-                if point.time == by_target:
-                    return point
+            if strict:
+                if point_type!=None:
+                    warnings.warn('`point_type` is not used when `strict` is set to True.')
+                for point in self.__points:
+                    if point.time == by_target:
+                        return point
+            
+            else:
+                points = self.__points.copy()
+
+                if point_type == None:
+                    pass
+                elif point_type == 'larger':
+                    points = [point for point in points if point.time >= by_target]
+                elif point_type == 'smaller':
+                    points = [point for point in points if point.time <= by_target]
+                else:
+                    raise Exception(
+                        '`point_type` can only by one of {`larger`, `smaller`, None}.'
+                    )
+
+                points.sort(key=lambda point: abs(point.time - by_target))
+
+                return points[0]
 
         elif by == _by.INDEX:
+            if point_type!=None:
+                warnings.warn('`point_type` is not used when by method is not `TIME`.')
+                
             try:
                 point = self.__points[by_target-1]
 
@@ -131,34 +156,12 @@ class Tier(object):
                     return point
 
         if not parameters['points.ignore_missing_point']:
+            if by==_by.TIME:
+                raise Exception('Point not found. Consider setting `strict` to False.')
             raise Exception('Point not found.')
-    
-    def get_closest_point(self, by_target, by, point_type=None):
-        
-        if by_target==_by.TIME:
-            points = self.__points.copy()
-            
-            if point_type==None:
-                pass
-            elif point_type=='larger':
-                points = [point for point in points if point.time>=time]
-            elif point_type=='smaller':
-                points = [point for point in points if point.time<=time]
-            else:
-                raise Exception(
-                    '`point_type` can only by one of {`larger`, `smaller`, None}.'
-                )
-            
-            points.sort(key=lambda point: (point.time - time))
-            
-            return points[0]
-        
-        else:
-            return self.get_point(by_target, by)
-        
 
     def get_points(self, by_target, by):
-        """Get a list of Point objects with chosen method. See \'help(by)\' for more information on the available methods. To change related parameters, use \'parameters\'."""
+        """Get a list of Point objects with chosen method. See `help(by)` for more information on the available methods. To change related parameters, use `parameters`."""
 
         points = []
 
@@ -166,7 +169,7 @@ class Tier(object):
             raise Exception(
                 f'Invalid by_method. Use help() to see valid methods.')
 
-        if by == 2:
+        if by == _by.POINT:
             for point in by_target:
                 if point in self.__points:
                     points.append(point)
@@ -175,11 +178,11 @@ class Tier(object):
                 else:
                     raise Exception('Point not found.')
 
-        elif by == 1:
+        elif by == _by.INDEX:
             for index in range(by_target[0], by_target[1]+1):
                 points.append(self.get_point(index, _by.INDEX))
 
-        elif by == 0:
+        elif by == _by.TIME:
             for point in self.__points:
                 if by_target[0] <= point.time <= by_target[1]:
                     points.append(point)
@@ -187,7 +190,7 @@ class Tier(object):
         return points
 
     def remove_point(self, by_target, by):
-        """Remove a Point object of the Tier with chosen method. See \'help(by)\' for more information on the available methods. To change related parameters, use \'parameters\'."""
+        """Remove a Point object of the Tier with chosen method. See `help(by)` for more information on the available methods. To change related parameters, use `parameters`."""
 
         if by not in _by.by_methods:
             raise Exception(
@@ -205,7 +208,7 @@ class Tier(object):
         self._indexed = True
 
     def remove_points(self, by_target, by):
-        """Remove Point objects of the Tier with chosen method. See \'help(by)\' for more information on the available methods. To change related parameters, use \'parameters\'."""
+        """Remove Point objects of the Tier with chosen method. See `help(by)` for more information on the available methods. To change related parameters, use `parameters`."""
 
         if by not in _by.by_methods:
             raise Exception(
@@ -224,7 +227,7 @@ class Tier(object):
         self._indexed = True
 
     def interpolate_points(self, by_target, by, step=.01, strict=True):
-        """Interpolate values between two Point objects (array-like), with given step (by default 0.01s). See \'help(by)\' for more information on the available methods. To change related parameters, use \'parameters\'."""
+        """Interpolate values between two Point objects (array-like), with given step (by default 0.01s). See `help(by)` for more information on the available methods. To change related parameters, use `parameters`."""
 
         if by not in _by.by_methods:
             raise Exception(
@@ -237,34 +240,37 @@ class Tier(object):
 
         original_ignore_missing_point_parameter = parameters['points.ignore_missing_point']
         parameters['points.ignore_missing_point'] = False
-        
+
         if by == _by.TIME and not strict:
-            points = self.get_closest_point(min(by_target), by, point_type='smaller'), self.get_closest_point(max(by_target), by, point_type='larger')
-        
+            points = self.get_point(min(by_target), by, strict=strict, point_type='smaller'), self.get_point(max(by_target), by, strict=strict, point_type='larger')
+
         else:
-            points = self.get_points(by_target, by)
-        
+            points = self.get_point(
+                by_target[0], by), self.get_point(by_target[1], by)
+
         if points[0].time <= points[1].time:
             point1, point2 = points[0], points[1]
         else:
             point1, point2 = points[1], points[0]
 
         self.remove_points((point1.time, point2.time), _by.TIME)
-        
-        interpolated_point_times = np.arange(point1.time, point2.time, step)[1:]
-        
-        interpolated_points = [Point(time, value, superior_Tier=self) for time, value in zip(interpolated_point_times, np.interp(interpolated_point_times, [point1.time, point2.time], [point1.value, point2.value]))]
-        
-        self.add_points(interpolated_points, _by.POINT)
+
+        interpolated_point_times = np.arange(
+            point1.time, point2.time, step)[1:]
+
+        interpolated_points = [Point(time, value, superior_Tier=self) for time, value in zip(
+            interpolated_point_times, np.interp(interpolated_point_times, [point1.time, point2.time], [point1.value, point2.value]))]
+
+        self.add_points(interpolated_points)
 
         self._indexed = False
         self._reindex()
         self._indexed = True
-        
+
         parameters['points.ignore_missing_point'] = original_ignore_missing_point_parameter
 
     def shift_point_to_time(self, target_time, by_target, by):
-        """Shift Point of the Tier to chosen time with chosen method. To change related parameters, use \'parameters\'."""
+        """Shift Point of the Tier to chosen time with chosen method. To change related parameters, use `parameters`."""
 
         if by not in _by.by_methods:
             raise Exception(
@@ -284,7 +290,7 @@ class Tier(object):
             self.add_point(point)
 
     def batch_raise_value(self, by_target, by, value):
-        """Batch raise or lower value of points of the Tier. To change related parameters, use \'parameters\'."""
+        """Batch raise or lower value of points of the Tier. To change related parameters, use `parameters`."""
 
         points = self.get_points(by_target, by)
 
@@ -314,7 +320,7 @@ class Tier(object):
         return df
 
     def write_to_file(self, file=''):
-        """Write the Tier to file. By default saves to the original directory, if any. To change related parameters, use \'parameters\'."""
+        """Write the Tier to file. By default saves to the original directory, if any. To change related parameters, use `parameters`."""
 
         if file == '':
             file = f'{self.original_dir}/{self.name}.{self.tier_type}'
@@ -329,7 +335,7 @@ class Tier(object):
                     file = f'{original_dir}/{file_name}.{file_extension}'
                 else:
                     raise Exception(
-                        f'{file} already exists. If you wish to replace it, set \'replace\' to True. If you wish to duplicate it, set \'duplicate\' to True.')
+                        f'{file} already exists. If you wish to replace it, set `replace` to True. If you wish to duplicate it, set `duplicate` to True.')
 
         with open(file, 'w') as f:
             f.writelines(
@@ -506,7 +512,7 @@ class Point(object):
             self.__point_index = point_index
 
         else:
-            raise AttributeError('can\'t set attribute')
+            raise AttributeError('can`t set attribute')
 
     @property
     def superior_Tier(self):
